@@ -16,80 +16,68 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
     Basic driver API class.
     """
 
-    driver_name = None
+    driver_name = ''
 
     @property
     def title(self):
-        """
-        Title of current page.
-        """
+        """Title of current page."""
         raise NotImplementedError(
             "%s doesn't support access to the title." % self.driver_name
         )
 
     def __enter__(self):
-        """
-        Context manager to use the browser safely.
-        """
+        """Context manager to use the browser safely."""
         raise NotImplementedError(
             "%s doesn't support use by 'with' statement." % self.driver_name
         )
 
     def __exit__(self):
-        """
-        Context manager to use the browser safely.
-        """
+        """Context manager to use the browser safely."""
         raise NotImplementedError(
             "%s doesn't support use by 'with' statement." % self.driver_name
         )
 
     @property
     def html(self):
-        """
-        Source of current page.
-        """
+        """Source of current page."""
         raise NotImplementedError(
             "%s doesn't support access to the html." % self.driver_name
         )
 
     @property
     def url(self):
-        """
-        URL of current page.
-        """
+        """URL of current page."""
         raise NotImplementedError(
             "%s doesn't support access to the url." % self.driver_name
         )
 
     def visit(self, url):
-        """
-        Visits a given URL.
+        """The browser will navigate to the given URL.
 
-        The ``url`` parameter is a string.
+        Arguments:
+            url (str): URL path.
         """
         raise NotImplementedError("%s doesn't visit any url." % self.driver_name)
 
     def new_tab(self, url):
-        """
-        Visits a given URL in a new tab.
+        """The browser will navigate to the given URL in a new tab.
 
-        The ``url`` parameter is a string.
+        Arguments:
+            url (str): URL path.
         """
         raise NotImplementedError("%s doesn't open a new tab." % self.driver_name)
 
     def back(self):
-        """
-        Back to the last URL in the browsing history.
+        """The browser will navigate to the previous URL in the history.
 
-        If there is no URL to back, this method does nothing.
+        If there is no previous URL, this method does nothing.
         """
         raise NotImplementedError(
             "%s doesn't support moving back in history." % self.driver_name
         )
 
     def forward(self):
-        """
-        Forward to the next URL in the browsing history.
+        """The browser will navigate to the next URL in the history.
 
         If there is no URL to forward, this method does nothing.
         """
@@ -98,34 +86,33 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def reload(self):
-        """
-        Revisits the current URL
-        """
+        """Revisits the current URL."""
         raise NotImplementedError(
             "%s doesn't support reloading the page." % self.driver_name
         )
 
     def get_alert(self):
-        """
-        Changes the context for working with alerts and prompts.
+        """Change the context for working with alerts and prompts.
 
         For more details, check the :doc:`docs about iframes, alerts and prompts </iframes-and-alerts>`
         """
         raise NotImplementedError("%s doesn't support alerts." % self.driver_name)
 
     def get_iframe(self, name):
-        """
-        Changes the context for working with iframes.
+        """Change the context for working with iframes.
 
         For more details, check the :doc:`docs about iframes, alerts and prompts </iframes-and-alerts>`
         """
         raise NotImplementedError("%s doesn't support frames." % self.driver_name)
 
     def execute_script(self, script, *args):
-        """
-        Executes a given JavaScript in the browser.
+        """Execute a piece of JavaScript in the browser.
+
+        Arguments:
+            script (str): The piece of JavaScript to execute.
+
+        Example:
 
-        e.g.: ::
             >>> browser.execute_script('document.getElementById("body").innerHTML = "<p>Hello world!</p>"')
         """
         raise NotImplementedError(
@@ -136,9 +123,13 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         """
         Similar to :meth:`execute_script <DriverAPI.execute_script>` method.
 
-        Executes javascript in the browser and returns the value of the expression.
+        Execute javascript in the browser and return the value of the expression.
+
+        Arguments:
+            script (str): The piece of JavaScript to execute.
+
+        Example:
 
-        e.g.: ::
             >>> assert 4 == browser.evaluate_script('2 + 2')
         """
         raise NotImplementedError(
@@ -147,8 +138,12 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
 
     def find_by_css(self, css_selector):
         """
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`,
+        Return an instance of :class:`ElementList <splinter.element_list.ElementList>`,
         using a CSS selector to query the current page content.
+
+        Arguments:
+            css_selector (str): CSS Selector to use in the search query.
+
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by css selector." % self.driver_name
@@ -156,69 +151,86 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
 
     def find_by_xpath(self, xpath):
         """
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`,
+        Return an instance of :class:`ElementList <splinter.element_list.ElementList>`,
         using a xpath selector to query the current page content.
+
+        Arguments:
+            xpath (str): Xpath to use in the search query.
+
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by xpath selector." % self.driver_name
         )
 
     def find_by_name(self, name):
-        """
-        Finds elements in current page by their name.
+        """Find elements on the current page by their name.
+
+        Return an instance of :class:`ElementList <splinter.element_list.ElementList>`.
+
+        Arguments:
+            name (str): name to use in the search query.
 
-        Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`.
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by name." % self.driver_name
         )
 
     def find_by_id(self, id):
-        """
-        Finds an element in current page by its id.
+        """Find an element on the current page by its id.
 
         Even when only one element is find, this method returns an instance of
         :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            id (str): id to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by id." % self.driver_name
         )
 
     def find_by_value(self, value):
-        """
-        Finds elements in current page by their value.
+        """Find elements on the current page by their value.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            value (str): value to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by value." % self.driver_name
         )
 
     def find_by_text(self, text):
-        """
-        Finds elements in current page by their text.
+        """Find elements on the current page by their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            text (str): text to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by text." % self.driver_name
         )
 
     def find_by_tag(self, tag):
-        """
-        Find all elements of a given tag in current page.
+        """Find all elements of a given tag in current page.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            tag (str): tag to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding elements by tag." % self.driver_name
         )
 
     def find_link_by_href(self, href):
-        """
-        Find all elements of a given tag in current page.
+        """Find all elements of a given tag in current page.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            href (str): href to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding links by href." % self.driver_name
@@ -229,6 +241,9 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         Find links by looking for a partial ``str`` in their href attribute.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            partial_href (str): partial_href to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding links by partial href." % self.driver_name
@@ -236,9 +251,12 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
 
     def find_link_by_text(self, text):
         """
-        Find links querying for their text.
+        Find links by querying for their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            text (str): text to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding links by text." % self.driver_name
@@ -249,6 +267,9 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         Find links by looking for a partial ``str`` in their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            partial_text (str): partial_text to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding links by partial text." % self.driver_name
@@ -256,9 +277,12 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
 
     def find_option_by_value(self, value):
         """
-        Finds ``<option>`` elements by their value.
+        Find ``<option>`` elements by their value.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            value (str): value to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding options by value." % self.driver_name
@@ -269,16 +293,23 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         Finds ``<option>`` elements by their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
+
+        Arguments:
+            text (str): text to use in the search query.
         """
         raise NotImplementedError(
             "%s doesn't support finding options by text." % self.driver_name
         )
 
     def is_text_present(self, text, wait_time=None):
-        """
-        Searchs for ``text`` in the browser and wait the seconds specified in ``wait_time``.
+        """Check if a piece of text is on the page.
 
-        Returns True if finds a match for the ``text`` and False if not.
+        Arguments:
+            text (str): text to use in the search query.
+            wait_time (int): Number of seconds to search for the text.
+
+        Returns:
+            bool: True if finds a match for the ``text`` and False if not.
         """
         raise NotImplementedError(
             "%s doesn't support checking if some text is present in the html. "
@@ -286,20 +317,25 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def type(self, name, value, slowly=False):
-        """
-        Types the ``value`` in the field identified by ``name``.
+        """Type a value into an element.
 
         It's useful to test javascript events like keyPress, keyUp, keyDown, etc.
 
-        If ``slowly`` is True, this function returns an iterator which will type one character per iteration.
+        Arguments:
+            name (str): name of the element to enter text into.
+            value (str): Value to enter into the element.
+            slowly (bool): If True, this function returns an iterator which will type one character per iteration.
         """
         raise NotImplementedError(
             "%s doesn't support typing on fields by name." % self.driver_name
         )
 
     def fill(self, name, value):
-        """
-        Fill the field identified by ``name`` with the content specified by ``value``.
+        """Fill the field identified by ``name`` with the content specified by ``value``.
+
+        Arguments:
+            name (str): name of the element to enter text into.
+            value (str): Value to enter into the element.
         """
         raise NotImplementedError(
             "%s doesn't support filling fields by name." % self.driver_name
@@ -325,23 +361,29 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def choose(self, name, value):
-        """
-        Chooses a value in a radio buttons group.
+        """Choose a value in a radio buttons group.
 
-        Suppose you have the two radio buttons in a page, with the name ``gender`` and values 'F' and 'M'.
-        If you use the ``choose`` method the following way:
+        Arguments:
+            name (str): name of the element to enter text into.
+            value (str): Value to choose.
+
+        Example:
+
+            You have two radio buttons in a page, with the name ``gender`` and values 'F' and 'M'.
 
             >>> browser.choose('gender', 'F')
 
-        Then you're choosing the female gender.
+            Then the female gender will be chosen.
         """
         raise NotImplementedError(
             "%s doesn't support choosing options." % self.driver_name
         )
 
     def check(self, name):
-        """
-        Checks a checkbox by its name.
+        """Check a checkbox by its name.
+
+        Arguments:
+            name (str): name of the element to check.
 
         Example:
 
@@ -349,15 +391,17 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
 
         If you call ``browser.check`` n times, the checkbox keeps checked, it never get unchecked.
 
-        To unckech a checkbox, take a look in the :meth:`uncheck <DriverAPI.uncheck>` method.
+        To uncheck a checkbox, take a look in the :meth:`uncheck <DriverAPI.uncheck>` method.
         """
         raise NotImplementedError(
             "%s doesn't support checking elements." % self.driver_name
         )
 
     def uncheck(self, name):
-        """
-        Unchecks a checkbox by its name.
+        """Uncheck a checkbox by its name.
+
+        Arguments:
+            name (str): name of the element to uncheck.
 
         Example:
 
@@ -373,9 +417,13 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
 
     def select(self, name, value):
         """
-        Selects an ``<option>`` element in an ``<select>`` element using the ``name`` of the ``<select>`` and
+        Select an ``<option>`` element in an ``<select>`` element using the ``name`` of the ``<select>`` and
         the ``value`` of the ``<option>``.
 
+        Arguments:
+            name (str): name of the option element.
+            value (str): Value to select.
+
         Example:
 
             >>> browser.select("state", "NY")
@@ -386,26 +434,34 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def click_link_by_href(self, href):
-        """
-        Clicks in a link by its ``href`` attribute.
+        """Click in a link by its ``href`` attribute.
+
+        Arguments:
+            href (str): href of the element to click.
         """
         return self.find_link_by_href(href).first.click()
 
     def click_link_by_partial_href(self, partial_href):
-        """
-        Clicks in a link by looking for partial content of ``href`` attribute.
+        """Click in a link by looking for partial content of ``href`` attribute.
+
+        Arguments:
+            partial_href (str): href of the element to click.
         """
         return self.find_link_by_partial_href(partial_href).first.click()
 
     def click_link_by_text(self, text):
-        """
-        Clicks in a link by its ``text``.
+        """Click in a link by its text.
+
+        Arguments:
+            text (str): text of the element to click.
         """
         return self.find_link_by_text(text).first.click()
 
     def click_link_by_partial_text(self, partial_text):
-        """
-        Clicks in a link by partial content of its text.
+        """Click in a link by partial content of its text.
+
+        Arguments:
+            partial_text (str): text of the element to click.
         """
         return self.find_link_by_partial_text(partial_text).first.click()
 
@@ -416,19 +472,18 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         return self.find_by_id(id).first.click()
 
     def quit(self):
-        """
-        Quits the browser, closing its windows (if it has one).
-
-        After quit the browser, you can't use it anymore.
-        """
+        """Quit the browser, closing its windows (if it has one)."""
         raise NotImplementedError("%s doesn't support quit" % self.driver_name)
 
     def is_element_present_by_css(self, css_selector, wait_time=None):
-        """
-        Verify if the element is present in the current page by css, and wait the specified
-        time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            css (str): css selector for the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by css"
@@ -436,11 +491,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_css(self, css_selector, wait_time=None):
-        """
-        Verify if the element is not present in the current page by css, and wait the specified time
-        in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            css (str): css selector for the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by css"
@@ -448,11 +506,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_present_by_xpath(self, xpath, wait_time=None):
-        """
-        Verify if the element is present in the current page by xpath, and wait the specified
-        time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            xpath (str): xpath of the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by xpath"
@@ -460,11 +521,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_xpath(self, xpath, wait_time=None):
-        """
-        Verify if the element is not present in the current page by xpath,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            xpath (str): xpath of the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by xpath"
@@ -472,11 +536,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_present_by_tag(self, tag, wait_time=None):
-        """
-        Verify if the element is present in the current page by tag,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            tag (str): tag of the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by tag"
@@ -484,11 +551,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_tag(self, tag, wait_time=None):
-        """
-        Verify if the element is not present in the current page by tag,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            tag (str): tag of the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by tag"
@@ -496,11 +566,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_present_by_name(self, name, wait_time=None):
-        """
-        Verify if the element is present in the current page by name,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            name (str): name of the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by name"
@@ -508,11 +581,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_name(self, name, wait_time=None):
-        """
-        Verify if the element is not present in the current page by name,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            name (str): name of the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by name"
@@ -520,11 +596,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_present_by_value(self, value, wait_time=None):
-        """
-        Verify if the element is present in the current page by value,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            value (str): value in the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by value"
@@ -532,11 +611,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_value(self, value, wait_time=None):
-        """
-        Verify if the element is not present in the current page by value,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            value (str): value in the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by value"
@@ -544,11 +626,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_present_by_text(self, text, wait_time=None):
-        """
-        Verify if the element is present in the current page by text,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            text (str): text in the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by text"
@@ -556,11 +641,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_text(self, text, wait_time=None):
-        """
-        Verify if the element is not present in the current page by text,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            text (str): text in the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by text"
@@ -568,11 +656,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_present_by_id(self, id, wait_time=None):
-        """
-        Verify if the element is present in the current page by id,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is present in the current page.
 
-        Returns True if the element is present and False if is not present.
+        Arguments:
+            id (str): id for the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is present and False if is not present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is present by id"
@@ -580,11 +671,14 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def is_element_not_present_by_id(self, id, wait_time=None):
-        """
-        Verify if the element is present in the current page by id,
-        and wait the specified time in ``wait_time``.
+        """Verify if an element is not present in the current page.
 
-        Returns True if the element is not present and False if is present.
+        Arguments:
+            id (str): id for the element.
+            wait_time (int): Number of seconds to search.
+
+        Returns:
+            bool: True if the element is not present and False if is present.
         """
         raise NotImplementedError(
             "%s doesn't support verifying if element is not present by id"
@@ -592,8 +686,11 @@ class DriverAPI(InheritedDocs("_DriverAPI", (object,), {})):
         )
 
     def screenshot(self, name=None, suffix=None):
-        """
-        Takes a screenshot of the current page and saves it locally.
+        """Take a screenshot of the current page and save it locally.
+
+        Arguments:
+            name (str): File name for the screenshot.
+            suffix (str): File extension for the screenshot.
         """
         raise NotImplementedError(
             "%s doesn't support taking screenshots." % self.driver_name
@@ -643,13 +740,13 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
 
     def click(self):
         """
-        Clicks in the element.
+        Click in the element.
         """
         raise NotImplementedError
 
     def check(self):
         """
-        Checks the element, if it's "checkable" (e.g.: a checkbox).
+        Check the element, if it's "checkable" (e.g.: a checkbox).
 
         If the element is already checked, this method does nothing. For unchecking
         elements, take a loot in the :meth:`uncheck <ElementAPI.uncheck>` method.
@@ -658,7 +755,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
 
     def uncheck(self):
         """
-        Unchecks the element, if it's "checkable" (e.g.: a checkbox).
+        Uncheck the element, if it's "checkable" (e.g.: a checkbox).
 
         If the element is already unchecked, this method does nothing. For checking
         elements, take a loot in the :meth:`check <ElementAPI.check>` method.
@@ -694,20 +791,18 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
 
     def mouse_over(self):
         """
-        Puts the mouse over the element.
+        Put the mouse over the element.
         """
         raise NotImplementedError
 
     def mouse_out(self):
         """
-        Moves the mouse away from the element.
+        Move the mouse away from the element.
         """
         raise NotImplementedError
 
     def clear(self):
-        """
-        Reset the field value.
-        """
+        """Reset the field value."""
         raise NotImplementedError
 
     def fill(self, value):
@@ -718,7 +813,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
 
     def type(self, value, slowly=False):
         """
-        Types the ``value`` in the field.
+        Type the ``value`` in the field.
 
         It's useful to test javascript events like keyPress, keyUp, keyDown, etc.
 
@@ -727,6 +822,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
         Also supports selenium.
 
         Example:
+
             >>> from selenium.webdriver.common.keys import Keys
             >>> ElementAPI.type(Keys.RETURN)
 
@@ -735,7 +831,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
 
     def select(self, value, slowly=False):
         """
-        Selects an ``<option>`` element in the element using the ``value`` of the ``<option>``.
+        Select an ``<option>`` element in the element using the ``value`` of the ``<option>``.
 
         Example:
 
@@ -744,9 +840,7 @@ class ElementAPI(InheritedDocs("_ElementAPI", (object,), {})):
         raise NotImplementedError
 
     def screenshot(self):
-        """
-        Take screenshot of the element.
-        """
+        """Take screenshot of the element."""
         raise NotImplementedError
 
     def __getitem__(self, attribute):
