@@ -12,23 +12,13 @@ if sys.version_info[0] > 2:
 else:
     from urlparse import urlparse  # NOQA
 
-import warnings
-
 
 class CookieManager(CookieManagerAPI):
-    def add(self, cookies):
-        if isinstance(cookies, list):
-            warnings.warn(
-                'Using a list of cookies is deprecated.'
-                ' Version 0.16.0 will only accept one cookie at a time.',
-                FutureWarning,
-            )
-            for cookie in cookies:
-                for key, value in cookie.items():
-                    self.driver.add_cookie({"name": key, "value": value})
-            return
-        for key, value in cookies.items():
-            self.driver.add_cookie({"name": key, "value": value})
+    def add(self, cookie, **kwargs):
+        for key, value in cookie.items():
+            kwargs['name'] = key
+            kwargs['value'] = value
+            self.driver.add_cookie(kwargs)
 
     def delete(self, *cookies):
         if cookies:
