@@ -20,6 +20,7 @@ class WebDriver(BaseWebDriver):
 
     def __init__(
         self,
+        options=None,
         profile=None,
         extensions=None,
         user_agent=None,
@@ -40,7 +41,7 @@ class WebDriver(BaseWebDriver):
         firefox_capabilities = DesiredCapabilities().FIREFOX
         firefox_capabilities["marionette"] = True
 
-        firefox_options = Options()
+        options = options or Options()
 
         if capabilities:
             for key, value in capabilities.items():
@@ -58,15 +59,15 @@ class WebDriver(BaseWebDriver):
                 firefox_profile.add_extension(extension)
 
         if headless:
-            firefox_options.add_argument("--headless")
+            options.add_argument("--headless")
 
         if incognito:
-            firefox_options.add_argument("-private")
+            options.add_argument("-private")
 
         self.driver = Firefox(
             firefox_profile,
             capabilities=firefox_capabilities,
-            options=firefox_options,
+            options=options,
             timeout=timeout,
             **kwargs
         )
