@@ -9,7 +9,6 @@ from __future__ import unicode_literals
 import mimetypes
 import re
 import time
-import warnings
 
 import lxml.html
 from lxml.cssselect import CSSSelector
@@ -24,19 +23,14 @@ from splinter.cookie_manager import CookieManagerAPI
 
 
 class CookieManager(CookieManagerAPI):
-    def add(self, cookies):
-        if isinstance(cookies, list):
-            warnings.warn(
-                'Using a list of cookies is deprecated.'
-                ' Version 0.16.0 will only accept one cookie at a time.',
-                FutureWarning,
-            )
-            for cookie in cookies:
-                for key, value in cookie.items():
-                    self.driver.cookies[key] = value
-            return
-        for key, value in cookies.items():
-            self.driver.cookies[key] = value
+    def add(self, cookie, **kwargs):
+        for key, value in cookie.items():
+            kwargs['name'] = key
+            kwargs['value'] = value
+            if key not in self.driver.cookies:
+                self.driver.cookies.create(**kwargs)
+            else:
+                self.driver.cookies.change(**kwargs)
 
     def delete(self, *cookies):
         if cookies:
